@@ -16,7 +16,7 @@ class FoxTR(Plugin):
            foxplay.com.tr/.*)
     """, re.VERBOSE)
 
-    playervars_re = re.compile(r"source\s*:\s*\[\s*\{\s*videoSrc\s*:\s*'(.*?)'", re.DOTALL)
+    playervars_re = re.compile(r"source\s*:\s*\[\s*\{\s*videoSrc\s*:\s*(?:mobilecheck\(\)\s*\?\s*)?'([^']+)'")
 
     @classmethod
     def can_handle_url(cls, url):
